==> SpecMate-0.54.0.tar.gz: SpecMate-0.54.0/specmate_globals.py <==
#!/usr/bin/python -O
# -*- coding: iso-8859-15 -*-

##    Copyright 2012, Momme Winkelnkemper <specmate@posteo.de>
##
##    This file is part of SpecMate.
##
##    SpecMate is free software: you can redistribute it and/or modify
##    it under the terms of the GNU General Public License as published by
##    the Free Software Foundation, either version 3 of the License, or
##    (at your option) any later version.
##
##    Specmate is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
##    You should have received a copy of the GNU General Public License
##    along with SpecMate.  If not, see <http://www.gnu.org/licenses/>.
"""
This files stores global variables for Specmate
"""
#----------------------------------------------------------------------------
# Globals to be kept 
#----------------------------------------------------------------------------
appName		=	"SpecMate"
author 		=	"Momme Winkelnkemper"
copyright 	=	"(c) 2012-2013, Momme Winkelnkemper\n<specmate@posteo.de>"
credits 	=	["Momme Winkelnkemper", "Elisabeth Siebert"]
developers	=	["Momme Winkelnkemper"]
license	 	=	"GPL "
license_long	=   	"SpecMate is free software: you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation, either version 3 of the License, or\n(at your option) any later version.\n\nSpecmate is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with SpecMate.  If not, see <http://www.gnu.org/licenses/>."
version		=	"0.54.0"
maintainer 	=	"Momme Winkelnkemper"
email		=	"specmate@posteo.de"
status		=	"Development"
description	=	"A graphical tool to analyse spectroscopic data."
long_descr	=	"SpecMate is a graphical tool to analyse spectroscopic data.\nCurrently it offers three main features:\n1) Background removal, 2) Comparison to (and subtraction of) reference datasets,\n3) Peak fitting(Gauss/Lorentz/Voigt)."  
#----------------------------------------------------------------------------
#----------------------------------------------------------------------------


#----------------------------------------------------------------------------
# Open globals to be resolved
#----------------------------------------------------------------------------
#SLIDER1_ID=11
#MAX_RES=1000.0
#graphTitle="Graph Title"
#xAxisLabel="X-Axis Label"
#yAxisLabel="Y-Axis Label"
#residualLabel="Residual"
#DEFAULT_REFSETTINGS=[0.5]
#DEFAULT_REFSETTINGS={'coeff': 0.5, 'name': 'None'}
DEFAULT_REF_COEFF=0.5
#plugin_path =   "./plugins/" 

labelStr={"xLabelName": "Axis Label (X)","yLabelName": "Axis Label (Y)","graphTitleName": "Graph Title","residualName": "Residual Name","baselineName": "Baseline Name"}
DEFAULT_LABELS={labelStr["xLabelName"]: "X-Axis Label", labelStr["yLabelName"]: "Y-Axis Label", labelStr["graphTitleName"]: "None"}
DEFAULT_NAMES={labelStr["residualName"]: "Residual",labelStr["baselineName"]: "Baseline"}

#----------------------------------------------------------------------------
#----------------------------------------------------------------------------

==> SpecMate-0.54.4.tar.gz: SpecMate-0.54.4/specmate_globals.py <==
#!/usr/bin/python -O
# -*- coding: iso-8859-15 -*-

##    Copyright 2012, Momme Winkelnkemper <specmate@posteo.de>
##
##    This file is part of SpecMate.
##
##    SpecMate is free software: you can redistribute it and/or modify
##    it under the terms of the GNU General Public License as published by
##    the Free Software Foundation, either version 3 of the License, or
##    (at your option) any later version.
##
##    Specmate is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
##    You should have received a copy of the GNU General Public License
##    along with SpecMate.  If not, see <http://www.gnu.org/licenses/>.
"""
This files stores global variables for SpecMate
"""
#----------------------------------------------------------------------------
# Globals to be kept 
#----------------------------------------------------------------------------
appName		=	"SpecMate"
author 		=	"Momme Winkelnkemper"
copyright 	=	"(c) 2012-2013, Momme Winkelnkemper\n<specmate@posteo.de>"
credits 	=	["Momme Winkelnkemper", "Elisabeth Siebert"]
developers	=	["Momme Winkelnkemper"]
license	 	=	"GPL "
license_long	=   	"SpecMate is free software: you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation, either version 3 of the License, or\n(at your option) any later version.\n\nSpecmate is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with SpecMate.  If not, see <http://www.gnu.org/licenses/>."
version		=	"0.54.4"
maintainer 	=	"Momme Winkelnkemper"
email		=	"specmate@posteo.de"
status		=	"Development"
description	=	"A graphical tool to analyze spectroscopic data."
long_descr	=	"SpecMate is a graphical tool to analyze spectroscopic data.\nCurrently it offers three main features:\n1) Background removal, 2) Comparison to (and subtraction of) reference datasets,\n3) Peak fitting(Gauss/Lorentz/Voigt)."  
#----------------------------------------------------------------------------
#----------------------------------------------------------------------------


#----------------------------------------------------------------------------
# Open globals to be resolved
#----------------------------------------------------------------------------
#SLIDER1_ID=11
#MAX_RES=1000.0
#graphTitle="Graph Title"
#xAxisLabel="X-Axis Label"
#yAxisLabel="Y-Axis Label"
#residualLabel="Residual"
#DEFAULT_REFSETTINGS=[0.5]
#DEFAULT_REFSETTINGS={'coeff': 0.5, 'name': 'None'}
DEFAULT_REF_COEFF=0.5
#plugin_path =   "./plugins/" 

labelStr={"xLabelName": "Axis Label (X)","yLabelName": "Axis Label (Y)","graphTitleName": "Graph Title","residualName": "Residual Name","baselineName": "Baseline Name"}
DEFAULT_LABELS={labelStr["xLabelName"]: "X-Axis Label", labelStr["yLabelName"]: "Y-Axis Label", labelStr["graphTitleName"]: "None"}
DEFAULT_NAMES={labelStr["residualName"]: "Residual",labelStr["baselineName"]: "Baseline"}

#----------------------------------------------------------------------------
#----------------------------------------------------------------------------
